==> centreon-web-24.10.16.tar.gz: centreon-web-24.10.16/src/Core/Resources/Infrastructure/API/CountResources/CountResourcesRequestTransformer.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Resources\Infrastructure\API\CountResources;

use Centreon\Domain\Contact\Interfaces\ContactInterface;
use Centreon\Domain\Monitoring\ResourceFilter;
use Core\Resources\Application\UseCase\CountResources\CountResourcesRequest;

/**
 * Class
 *
 * @class CountResourcesRequestTransformer
 * @package Core\Resources\Infrastructure\API\CountResources
 */
final readonly class CountResourcesRequestTransformer {
    /**
     * @param CountResourcesInput $input
     * @param ResourceFilter $resourceFilter
     * @param ContactInterface $contact
     *
     * @return CountResourcesRequest
     */
    public static function transform(
        CountResourcesInput $input,
        ResourceFilter $resourceFilter,
        ContactInterface $contact
    ): CountResourcesRequest {
        return new CountResourcesRequest(
            resourceFilter: $resourceFilter,
            allPages: $input->allPages,
            contactId: $contact->getId(),
            isAdmin: $contact->isAdmin()
        );
    }
}

==> centreon-web-25.09.2.tar.gz: centreon-web-25.09.2/src/Core/Resources/Infrastructure/API/CountResources/CountResourcesRequestTransformer.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Resources\Infrastructure\API\CountResources;

use Centreon\Domain\Contact\Interfaces\ContactInterface;
use Centreon\Domain\Monitoring\ResourceFilter;
use Core\Resources\Application\UseCase\CountResources\CountResourcesRequest;

/**
 * Class
 *
 * @class CountResourcesRequestTransformer
 * @package Core\Resources\Infrastructure\API\CountResources
 */
final readonly class CountResourcesRequestTransformer
{
    /**
     * @param CountResourcesInput $input
     * @param ResourceFilter $resourceFilter
     * @param ContactInterface $contact
     *
     * @return CountResourcesRequest
     */
    public static function transform(
        CountResourcesInput $input,
        ResourceFilter $resourceFilter,
        ContactInterface $contact
    ): CountResourcesRequest {
        return new CountResourcesRequest(
            resourceFilter: $resourceFilter,
            allPages: $input->allPages,
            contactId: $contact->getId(),
            isAdmin: $contact->isAdmin()
        );
    }
}
